@@ -5,7 +5,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -19,7 +19,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  *
@@ -32,7 +32,7 @@
  * @property-read boolean $multipart Indicate this is a multipart request.
  * @property-read string $certPath Local path to the certificate bundle.
  * @property-read Horde_ActiveSync_Device $device  The current device object.
- * @property-read Horde_Log_Logger $logger   The logger object.
+ * @property-read Horde_ActiveSync_Log_Logger $logger   The logger object.
  */
 class Horde_ActiveSync
 {
@@ -320,7 +320,7 @@ class Horde_ActiveSync
     /* Internal flag indicates all possible fields are ghosted */
     const ALL_GHOSTED                           = 'allghosted';
 
-    const LIBRARY_VERSION                       = '2.37.4';
+    const LIBRARY_VERSION                       = '2.38.7';
 
     /**
      * Logger
@@ -561,10 +561,7 @@ class Horde_ActiveSync
     {
         if (!$credentials->username) {
             // No provided username or Authorization header.
-            self::$_logger->notice(sprintf(
-                '[%s] Client did not provide authentication data.',
-                $this->_procid)
-            );
+            self::$_logger->notice('Client did not provide authentication data.');
             return false;
         }
 
@@ -650,21 +647,26 @@ class Horde_ActiveSync
     }
 
     /**
-     * Setter for the logger
+     * Setter for the logger factory.
      *
-     * @param Horde_Log_Logger $logger  The logger object.
-     *
-     * @return void
+     * @param Horde_ActiveSync_Interface_LoggerFactory $logger  The logger factory.
      */
     public function setLogger(Horde_ActiveSync_Interface_LoggerFactory $logger)
     {
         $this->_loggerFactory = $logger;
     }
 
+    /**
+     * Instantiate the logger from the factory and inject into all needed
+     * objects.
+     *
+     * @param array $options [description]
+     */
     protected function _setLogger(array $options)
     {
         if (!empty($this->_loggerFactory)) {
-            self::$_logger = $this->_loggerFactory->create($options);
+            // @TODO. Remove wrapper.
+            self::$_logger = self::_wrapLogger($this->_loggerFactory->create($options));
             $this->_encoder->setLogger(self::$_logger);
             $this->_decoder->setLogger(self::$_logger);
             $this->_driver->setLogger(self::$_logger);
@@ -672,6 +674,15 @@ class Horde_ActiveSync
         }
     }
 
+    public static function _wrapLogger(Horde_Log_Logger $logger)
+    {
+        if (!($logger instanceof Horde_ActiveSync_Log_Logger)) {
+            return new Horde_ActiveSync_Log_Logger_Deprecated(null, $logger);
+        }
+
+        return $logger;
+    }
+
     /**
      * Setter for provisioning support
      *
@@ -747,8 +758,8 @@ class Horde_ActiveSync
         }
 
         self::$_logger->info(sprintf(
-            '[%s] %s request received for user %s',
-            $this->_procid,
+            '%s%s request received for user %s',
+            str_repeat('-', 10),
             Horde_String::upper($cmd),
             $this->_driver->getUser())
         );
@@ -761,7 +772,7 @@ class Horde_ActiveSync
         // Device id is REQUIRED
         if (empty($devId)) {
             if ($cmd == 'Options') {
-                $this->_doOptionsRequest();
+                $this->_handleOptionsRequest();
                 $this->_driver->clearAuthentication();
                 return true;
             }
@@ -784,7 +795,7 @@ class Horde_ActiveSync
 
         // Don't bother with everything else if all we want are Options
         if ($cmd == 'Options') {
-            $this->_doOptionsRequest();
+            $this->_handleOptionsRequest();
             $this->_driver->clearAuthentication();
             return true;
         }
@@ -800,10 +811,7 @@ class Horde_ActiveSync
         if ((!empty($headers['ms-asacceptmultipart']) && $headers['ms-asacceptmultipart'] == 'T') ||
             !empty($get['AcceptMultiPart'])) {
             $this->_multipart = true;
-            self::$_logger->info(sprintf(
-                '[%s] Requesting multipart data.',
-                $this->_procid)
-            );
+            self::$_logger->info('Requesting multipart data.');
         }
 
         // Load the request handler to handle the request
@@ -817,10 +825,7 @@ class Horde_ActiveSync
 
         // Should we announce a new version is available to the client?
         if (!empty($this->_needMsRp)) {
-            self::$_logger->info(sprintf(
-                '[%s] Announcing X-MS-RP to client.',
-                $this->_procid)
-            );
+            self::$_logger->info('Announcing X-MS-RP to client.');
             header("X-MS-RP: ". $this->getSupportedVersions());
         }
 
@@ -833,8 +838,7 @@ class Horde_ActiveSync
             $request->setLogger(self::$_logger);
             $result = $request->handle();
             self::$_logger->info(sprintf(
-                '[%s] Maximum memory usage for ActiveSync request: %d bytes.',
-                $this->_procid,
+                'Maximum memory usage for ActiveSync request: %d bytes.',
                 memory_get_peak_usage(true))
             );
 
@@ -968,40 +972,56 @@ class Horde_ActiveSync
 
     /**
      * Send the MS_Server-ActiveSync header.
+     *
+     * @return array Returns an array of the headers that were sent.
+     *     @since  2.39.0
      */
     public function activeSyncHeader()
     {
-        header('Allow: OPTIONS,POST');
-        header('Server: Horde_ActiveSync Library v' . self::LIBRARY_VERSION);
-        header('Public: OPTIONS,POST');
+        $headers = array(
+            'Allow: OPTIONS,POST',
+            sprintf('Server: Horde_ActiveSync Library v%s', self::LIBRARY_VERSION),
+            'Public: OPTIONS,POST'
+        );
 
         switch ($this->_maxVersion) {
         case self::VERSION_TWOFIVE:
-            header('MS-Server-ActiveSync: 6.5.7638.1');
+            $headers[] = 'MS-Server-ActiveSync: 6.5.7638.1';
             break;
         case self::VERSION_TWELVE:
-            header('MS-Server-ActiveSync: 12.0');
+            $headers[] = 'MS-Server-ActiveSync: 12.0';
             break;
         case self::VERSION_TWELVEONE:
-            header('MS-Server-ActiveSync: 12.1');
+            $headers[] = 'MS-Server-ActiveSync: 12.1';
             break;
         case self::VERSION_FOURTEEN:
-            header('MS-Server-ActiveSync: 14.0');
+            $headers[] = 'MS-Server-ActiveSync: 14.0';
             break;
         case self::VERSION_FOURTEENONE:
-            header('MS-Server-ActiveSync: 14.1');
+            $headers[] = 'MS-Server-ActiveSync: 14.1';
             break;
         case self::VERSION_SIXTEEN:
-            header('MS-Server-ActiveSync: 16.0');
+            $headers[] = 'MS-Server-ActiveSync: 16.0';
         }
+
+        foreach ($headers as $hdr) {
+            header($hdr);
+        }
+
+        return $headers;
     }
 
     /**
      * Send the protocol versions header.
+     *
+     * @return  string  The header that was sent. @since 2.39.0
      */
     public function versionHeader()
     {
-        header('MS-ASProtocolVersions: ' . $this->getSupportedVersions());
+        $hdr = sprintf('MS-ASProtocolVersions: %s', $this->getSupportedVersions());
+        header($hdr);
+
+        return $hdr;
     }
 
     /**
@@ -1017,10 +1037,15 @@ class Horde_ActiveSync
 
     /**
      * Send protocol commands header.
+     *
+     * @return string  The header that was sent. @since 2.39.0
      */
     public function commandsHeader()
     {
-        header('MS-ASProtocolCommands: ' . $this->getSupportedCommands());
+        $hdr = sprintf('MS-ASProtocolCommands: %s', $this->getSupportedCommands());
+        header($hdr);
+
+        return $hdr;
     }
 
     /**
@@ -1167,11 +1192,15 @@ class Horde_ActiveSync
     /**
      * Send the OPTIONS request response headers.
      */
-    protected function _doOptionsRequest()
+    protected function _handleOptionsRequest()
     {
-        $this->activeSyncHeader();
-        $this->versionHeader();
-        $this->commandsHeader();
+        $as_headers = implode("\r\n", $this->activeSyncHeader());
+        $version_header = $this->versionHeader();
+        $cmd_header = $this->commandsHeader();
+        self::$_logger->meta(sprintf(
+            "Returning OPTIONS response:\r\n%s\r\n%s\r\n%s",
+            $as_headers, $version_header, $cmd_header)
+        );
     }
 
     /**
@@ -1220,7 +1249,7 @@ class Horde_ActiveSync
      *                          falso if no truncation.
      *
      */
-    public function getTruncSize($truncation)
+    public static function getTruncSize($truncation)
     {
         switch($truncation) {
         case Horde_ActiveSync::TRUNCATION_ALL:
