@@ -7,7 +7,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2013-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2013-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -20,7 +20,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2010-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2010-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  * @internal  Not intended for use outside of the ActiveSync library.
@@ -179,10 +179,10 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                 }
             }
             $this->_collections[$collection['id']] = $collection;
-            $this->_logger->info(sprintf(
-                '[%s] Loaded %s from the cache.',
-                $this->_procid,
-                $collection['serverid']));
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Loaded %s from the cache.',
+                $collection['serverid'])
+            );
         }
     }
 
@@ -276,8 +276,10 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
     public function ensureOptions()
     {
         foreach ($this->_collections as &$collection) {
-            $this->_logger->info(sprintf(
-                '[%s] Loading default OPTIONS for %s collection.', $this->_procid, $collection['id']));
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Loading default OPTIONS for %s collection.',
+                $collection['id'])
+            );
 
             if (!isset($collection['mimesupport'])) {
                 $collection['mimesupport'] = Horde_ActiveSync::MIME_SUPPORT_NONE;
@@ -304,17 +306,22 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                 : 0;
 
             if ($collection['synckey'] === 0) {
-                $this->_logger->err(sprintf('[%s] Attempting to add a collection
+                $this->_logger->err('COLLECTIONS: Attempting to add a collection
                     to the sync cache while requiring a synckey, but no
                     synckey could be found. Most likely a client error in
                     requesting a collection during PING before it has issued a
-                    SYNC.', $this->_procid));
-                throw new Horde_ActiveSync_Exception_StateGone('Synckey required in Horde_ActiveSync_Collections::addCollection, but none was found.');
+                    SYNC.'
+                );
+                throw new Horde_ActiveSync_Exception_StateGone(
+                    'Synckey required in Horde_ActiveSync_Collections::addCollection, but none was found.'
+                );
             }
 
-            $this->_logger->info(sprintf(
-                '[%s] Obtained synckey for collection %s from cache: %s',
-                $this->_procid, $collection['id'], $collection['synckey']));
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Obtained synckey for collection %s from cache: %s',
+                $collection['id'],
+                $collection['synckey'])
+            );
         }
 
         // Load the class if needed for EAS >= 12.1 and ensure we have the
@@ -330,11 +337,11 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         }
 
         $this->_collections[$collection['id']] = $collection;
-        $this->_logger->info(sprintf(
-            '[%s] Collection added to collection handler: collection: %s, synckey: %s.',
-            $this->_procid,
+        $this->_logger->meta(sprintf(
+            'COLLECTIONS: Collection added to collection handler: collection: %s, synckey: %s.',
             $collection['serverid'],
-            !empty($collection['synckey']) ? $collection['synckey'] : 'NONE'));
+            !empty($collection['synckey']) ? $collection['synckey'] : 'NONE')
+        );
     }
 
     /**
@@ -355,9 +362,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         if ($folder) {
             return $folder['serverid'];
         } else {
-            $this->_logger->err(
-                sprintf('[%s] Horde_ActiveSync_Collections::getBackendIdForFolderUid failed because folder was not found in cache.',
-                $this->_procid));
+            $this->_logger->err('COLLECTIONS: Horde_ActiveSync_Collections::getBackendIdForFolderUid failed because folder was not found in cache.');
             throw new Horde_ActiveSync_Exception_FolderGone('Folder not found in cache.');
         }
     }
@@ -481,9 +486,10 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         $collections = $this->_cache->getCollections();
         foreach (array_keys($this->_collections) as $id) {
             if (!empty($collections[$id])) {
-                $this->_logger->info(sprintf(
-                    '[%s] Refreshing %s from the cache.',
-                    $this->_procid, $id));
+                $this->_logger->meta(sprintf(
+                    'COLLECTIONS: Refreshing %s from the cache.',
+                    $id)
+                );
                 $this->_collections[$id] = $collections[$id];
             }
         }
@@ -510,9 +516,10 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // Next look in the SyncCache.
         if (isset($this->_cache->folders[$id]['class'])) {
             $class = $this->_cache->folders[$id]['class'];
-            $this->_logger->info(sprintf(
-                '[%s] Obtaining collection class of %s for collection id %s',
-                $this->_procid, $class, $id));
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Obtaining collection class of %s for collection id %s',
+                $class, $id)
+            );
             return $class;
         }
 
@@ -533,9 +540,10 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // Next look in the SyncCache.
         if (isset($this->_cache->folders[$id]['type'])) {
             $type = $this->_cache->folders[$id]['type'];
-            $this->_logger->info(sprintf(
-                '[%s] Obtaining collection type of %s for collection id %s',
-                $this->_procid, $type, $id));
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Obtaining collection type of %s for collection id %s',
+                $type, $id)
+            );
             return $type;
         }
 
@@ -554,13 +562,14 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
     {
         // Ensure we have syncable collections, using the cache if needed.
         if ($version >= Horde_ActiveSync::VERSION_TWELVEONE && empty($this->_collections)) {
-            $this->_logger->info('No collections - looking in sync_cache.');
+            $this->_logger->meta('COLLECTIONS: No collections loaded, looking in sync_cache.');
             $found = false;
             foreach ($this->_cache->getCollections() as $value) {
                 if (isset($value['synckey'])) {
-                    $this->_logger->info(sprintf(
-                        '[%s] Found a syncable collection: %s : %s. Adding it to the collections object.',
-                        $this->_procid, $value['serverid'], $value['synckey']));
+                    $this->_logger->meta(sprintf(
+                        'COLLECTIONS: Found syncable collection: %s : %s.',
+                        $value['serverid'], $value['synckey'])
+                    );
                     $this->_collections[$value['id']] = $value;
                     $found = true;
                 }
@@ -570,7 +579,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
             return false;
         }
 
-        $this->_logger->info('Have syncable collections');
+        $this->_logger->meta('COLLECTIONS: Have syncable collections!');
 
         return true;
     }
@@ -727,9 +736,8 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                 $syncFolder['displayname'] == $folder->displayname &&
                 $syncFolder['type'] == $folder->type) {
 
-                $this->_logger->info(sprintf(
-                    '[%s] Ignoring %s from changes because it contains no changes from device.',
-                    $this->_procid,
+                $this->_logger->meta(sprintf(
+                    'COLLECTIONS: Ignoring %s from changes because it contains no changes from device.',
                     $folder->serverid)
                 );
                 unset($exporter->changed[$key]);
@@ -740,9 +748,8 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // Remove unnecessary deletions.
         foreach ($exporter->deleted as $key => $folder) {
             if (($sid = array_search($folder, $seenfolders)) === false) {
-                $this->_logger->info(sprintf(
-                    '[%s] Ignoring %s from deleted list because the device does not know it',
-                    $this->_procid,
+                $this->_logger->meta(sprintf(
+                    'COLLECTIONS: Ignoring %s from deleted list because the device does not know it',
                     $folder)
                 );
                 unset($exporter->deleted[$key]);
@@ -784,8 +791,8 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
             // Remove keys from confirmed synckeys array and count them
             if (isset($value['synckey'])) {
                 if (isset($this->_cache->confirmed_synckeys[$value['synckey']])) {
-                    $this->_logger->info(sprintf(
-                        'Removed %s from confirmed_synckeys',
+                    $this->_logger->meta(sprintf(
+                        'COLLECTIONS: Removed %s from confirmed_synckeys',
                         $value['synckey'])
                     );
                     $this->_cache->removeConfirmedKey($value['synckey']);
@@ -794,7 +801,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
             }
         }
         if (!$this->_checkConfirmedKeys()) {
-            $this->_logger->err('Some synckeys were not confirmed, but handling an empty request. Requesting full SYNC');
+            $this->_logger->err('COLLECTIONS: Some synckeys were not confirmed, but handling an empty request. Requesting full SYNC');
             $this->save();
             return false;
         }
@@ -821,10 +828,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // Short circuit if we only have a changed ping/wait interval.
         if (empty($this->_collections)) {
             $emptyCollections = true;
-            $this->_logger->info(sprintf(
-                '[%s] No collections in collection handler, loading full collection set from cache.',
-                $this->_procid)
-            );
+            $this->_logger->meta('COLLECTIONS: No collections loaded, loading full collection set from cache.');
             $this->loadCollectionsFromCache();
 
         } else {
@@ -892,8 +896,8 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         foreach ($this->_collections as $value) {
             if (isset($value['synckey'])) {
                 if (isset($this->_cache->confirmed_synckeys[$value['synckey']])) {
-                    $this->_logger->info(sprintf(
-                        'Removed %s from confirmed_synckeys',
+                    $this->_logger->meta(sprintf(
+                        'COLLECTIONS: Removed %s from confirmed_synckeys',
                         $value['synckey'])
                     );
                     $this->_cache->removeConfirmedKey($value['synckey']);
@@ -903,16 +907,13 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         }
 
         if (!$this->_checkConfirmedKeys()) {
-            $this->_logger->warn('Some synckeys were not confirmed. Requesting full SYNC');
+            $this->_logger->warn('COLLECTIONS: Some synckeys were not confirmed. Requesting full SYNC');
             $this->save();
             return false;
         }
 
         if (!$emptyCollections && $this->_haveNoChangesInPartialSync()) {
-            $this->_logger->warn(sprintf(
-                '[%s] Partial Request with completely unchanged collections. Request a full SYNC',
-                $this->_procid)
-            );
+            $this->_logger->warn('COLLECTIONS: Partial Request with completely unchanged collections. Request a full SYNC');
             return false;
         }
 
@@ -923,9 +924,8 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
     {
         $csk = $this->_cache->confirmed_synckeys;
         if ($csk) {
-            $this->_logger->info(sprintf(
-                '[%s] Confirmed Synckeys contains %s',
-                $this->_procid,
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Confirmed Synckeys contains %s',
                 serialize($csk))
             );
             return false;
@@ -979,8 +979,8 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
             if (!empty($this->_collections[$value['id']])) {
                 continue;
             }
-            $this->_logger->info(sprintf(
-                'Using SyncCache State for %s',
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Using SyncCache State for %s',
                 $value['serverid']
             ));
             if (empty($value['synckey'])) {
@@ -1004,9 +1004,10 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         if (!empty($cc[$id]['filtertype']) &&
             !is_null($filter) &&
             $cc[$id]['filtertype'] != $filter) {
-            $this->_logger->info(sprintf(
-                '[%s] Filtertype change from: %d to %d',
-                $this->_procid, $cc[$id]['filtertype'], $filter));
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: Filtertype change from: %d to %d',
+                $cc[$id]['filtertype'], $filter)
+            );
             $this->_cache->updateFiltertype($id, $filter);
             return false;
         }
@@ -1037,7 +1038,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // folder cache before saving to ensure it isn't overwritten. See
         // Bug: 13273
         if ($preserve_folders && !$this->_cache->validateCache()) {
-            $this->_logger->info(sprintf('[%s] Updating the foldercache before saving.', $this->_procid));
+            $this->_logger->meta('COLLECTIONS: Updating the foldercache before saving.');
             $this->_cache->refreshFolderCache();
         }
 
@@ -1079,16 +1080,17 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
 
         if ($requireSyncKey && empty($collection['synckey'])) {
             throw new Horde_ActiveSync_Exception_InvalidRequest(sprintf(
-                '[%s] Empty synckey for %s.',
-                $this->_procid, $collection['id']));
+                'Empty synckey for %s.',
+                $collection['id'])
+            );
         }
 
         // Initialize the state
         $this->_logger->info(sprintf(
-            '[%s] Initializing state for collection: %s, synckey: %s',
-            $this->_procid,
+            'COLLECTIONS: Initializing state for collection: %s, synckey: %s',
             $collection['serverid'],
-            $collection['synckey']));
+            $collection['synckey'])
+        );
         $this->_as->state->loadState(
             $collection,
             $collection['synckey'],
@@ -1116,7 +1118,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         $until = $started + $heartbeat;
 
         $this->_logger->info(sprintf(
-            'Waiting for changes for %s seconds',
+            'COLLECTIONS: Waiting for changes for %s seconds',
             $heartbeat)
         );
 
@@ -1124,7 +1126,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // filter on them here because the collections might change during the
         // loop below.
         if (!empty($options['pingable']) && !$this->havePingableCollections()) {
-            $this->_logger->err('No pingable collections.');
+            $this->_logger->err('COLLECTIONS: No pingable collections.');
             return self::COLLECTION_ERR_SERVER;
         }
 
@@ -1176,8 +1178,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                     $this->initCollectionState($collection, true);
                 } catch (Horde_ActiveSync_Exception_StateGone $e) {
                     $this->_logger->notice(sprintf(
-                        '[%s] State not found for %s. Continuing.',
-                        $this->_procid,
+                        'COLLECTIONS: State not found for %s. Continuing.',
                         $id)
                     );
                     if (!empty($options['pingable'])) {
@@ -1191,16 +1192,16 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                     // collection has not yet been synched, but was requested to
                     // be pinged.
                     $this->_logger->err(sprintf(
-                        '[%s] Unable to initialize state for %s. Ignoring during pollForChanges: %s.',
-                        $this->_procid,
+                        'COLLECTIONS: Unable to initialize state for %s. Ignoring during pollForChanges: %s.',
                         $id,
-                        $e->getMessage()));
+                        $e->getMessage())
+                    );
                     continue;
                 } catch (Horde_ActiveSync_Exception_FolderGone $e) {
-                    $this->_logger->warn('Folder gone for collection ' . $collection['id']);
+                    $this->_logger->warn('COLLECTIONS: Folder gone for collection ' . $collection['id']);
                     return self::COLLECTION_ERR_FOLDERSYNC_REQUIRED;
                 } catch (Horde_ActiveSync_Exception $e) {
-                    $this->_logger->err('Error loading state: ' . $e->getMessage());
+                    $this->_logger->err('COLLECTIONS: Error loading state: ' . $e->getMessage());
                     $this->_as->state->loadState(
                         array(),
                         null,
@@ -1212,9 +1213,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                 }
 
                 if (!empty($options['pingable']) && !$this->_cache->collectionIsPingable($id)) {
-                    $this->_logger->notice(sprintf(
-                        '[%s] Skipping %s because it is not PINGable.',
-                        $this->_procid, $id));
+                    $this->_logger->notice(sprintf('COLLECTIONS: Skipping %s because it is not PINGable.', $id));
                     continue;
                 }
 
@@ -1234,8 +1233,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                     }
                 } catch (Horde_ActiveSync_Exception_StaleState $e) {
                     $this->_logger->notice(sprintf(
-                        '[%s] SYNC terminating and force-clearing device state: %s',
-                        $this->_procid,
+                        'COLLECTIONS: SYNC terminating and force-clearing device state: %s',
                         $e->getMessage())
                     );
                     $this->_as->state->loadState(
@@ -1247,8 +1245,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                     $dataavailable = true;
                 } catch (Horde_ActiveSync_Exception_FolderGone $e) {
                     $this->_logger->notice(sprintf(
-                        '[%s] SYNC terminating: %s',
-                        $this->_procid,
+                        'COLLECTIONS: SYNC terminating: %s',
                         $e->getMessage())
                     );
                     // If we are missing a folder, we should clear the PING
@@ -1259,15 +1256,11 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
                     return self::COLLECTION_ERR_FOLDERSYNC_REQUIRED;
                 } catch (Horde_Exception_AuthenticationFailure $e) {
                     // We lost authentication for some reason.
-                    $this->_logger->err(sprintf(
-                        '[%s] Authentication lost during PING!!',
-                        $this->_procid)
-                    );
+                    $this->_logger->err('COLLECTIONS: Authentication lost during PING!!');
                     return self::COLLECTION_ERR_AUTHENTICATION;
                 } catch (Horde_ActiveSync_Exception $e) {
                     $this->_logger->err(sprintf(
-                        '[%s] Sync object cannot be configured, throttling: %s',
-                        $this->_procid,
+                        'COLLECTIONS: Sync object cannot be configured, throttling: %s',
                         $e->getMessage())
                     );
                     $this->_sleep(30);
@@ -1276,10 +1269,7 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
             }
 
             if (!empty($dataavailable)) {
-                $this->_logger->info(sprintf(
-                    '[%s] Found changes!',
-                    $this->_procid)
-                );
+                $this->_logger->info('COLLECTIONS: Found changes!');
                 break;
             }
 
@@ -1293,14 +1283,13 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         // Check that no other Sync process already started
         // If so, we exit here and let the other process do the export.
         if ($this->checkStaleRequest()) {
-            $this->_logger->info('Changes in cache determined during Sync Wait/Heartbeat, exiting here.');
+            $this->_logger->meta('COLLECTIONS: Changes in cache determined during Sync Wait/Heartbeat, exiting here.');
 
             return self::COLLECTION_ERR_STALE;
         }
 
-        $this->_logger->info(sprintf(
-            '[%s] Looping Sync complete: DataAvailable: %s, DataImported: %s',
-            $this->_procid,
+        $this->_logger->meta(sprintf(
+            'COLLECTIONS: Looping Sync complete: DataAvailable: %s, DataImported: %s',
             $dataavailable,
             $this->importedChanges)
         );
@@ -1318,7 +1307,9 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
     {
         // Wait.
         $this->_logger->info(sprintf(
-            '[%s] Sleeping for %s seconds.', $this->_procid, $interval));
+            '%sCOLLECTIONS: Sleeping for %s seconds.',
+            str_repeat('-', 10),
+            $interval));
 
         // Close any backend connections.
         $this->_cache->state->disconnect();
@@ -1350,16 +1341,18 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
         $collections = $this->_cache->getCollections(false);
         foreach ($collections as $id => $collection) {
             if (!empty($this->_collections[$id]['synckey'])) {
-                $this->_logger->info(sprintf(
-                    'Setting collection %s (%s) PINGABLE.',
+                $this->_logger->meta(sprintf(
+                    'COLLECTIONS: Setting collection %s (%s) PINGABLE.',
                     $collection['serverid'],
-                    $id));
+                    $id)
+                );
                 $this->_cache->setPingableCollection($id);
             } else {
-                $this->_logger->info(sprintf(
-                    'UNSETTING collection %s (%s) PINGABLE flag.',
+                $this->_logger->meta(sprintf(
+                    'COLLECTIONS: UNSETTING collection %s (%s) PINGABLE flag.',
                     $collection['serverid'],
-                    $id));
+                    $id)
+                );
                 $this->_cache->removePingableCollection($id);
             }
         }
@@ -1374,10 +1367,11 @@ class Horde_ActiveSync_Collections implements IteratorAggregate
     {
         $collections = $this->_cache->getCollections(false);
         foreach ($collections as $id => $collection) {
-            $this->_logger->info(sprintf(
-                'UNSETTING collection %s (%s) PINGABLE flag.',
+            $this->_logger->meta(sprintf(
+                'COLLECTIONS: UNSETTING collection %s (%s) PINGABLE flag.',
                 $collection['serverid'],
-                $id));
+                $id)
+            );
             $this->_cache->removePingableCollection($id);
         }
     }
