@@ -7,7 +7,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2010-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2010-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -22,7 +22,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2010-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2010-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -125,10 +125,10 @@ abstract class Horde_ActiveSync_Driver_Base
         /* Create a stub if we don't have a useable logger. */
         if (isset($params['logger'])
             && is_callable(array($params['logger'], 'log'))) {
-            $this->_logger = $params['logger'];
+            $this->_logger = Horde_ActiveSync::_wrapLogger($params['logger']);
             unset($params['logger']);
         } else {
-            $this->_logger = new Horde_Log_Logger(new Horde_Log_Handler_Null());
+            $this->_logger = new Horde_ActiveSync_Log_Logger(new Horde_Log_Handler_Null());
         }
 
         $this->_state = $params['state'];
@@ -152,7 +152,7 @@ abstract class Horde_ActiveSync_Driver_Base
      */
     public function setLogger($logger)
     {
-        $this->_logger = $logger;
+        $this->_logger = Horde_ActiveSync::_wrapLogger($logger);
     }
 
     /**
@@ -351,7 +351,7 @@ abstract class Horde_ActiveSync_Driver_Base
         }
 
         // Now put in the busy blocks.
-        while (list($b_start, $b_end) = each($fb->b)) {
+        foreach ($fb->b as $b_start => $b_end) {
             $offset = $b_start - $start->timestamp();
             $duration = ceil(($b_end - $b_start) / 1800);
             if ($offset > 0) {
@@ -411,11 +411,11 @@ abstract class Horde_ActiveSync_Driver_Base
 
         // None found, generate a new UID.
         $this->_tempMap[$id] = sprintf('%s%04x%04x', $prefix, mt_rand(0, 0xffff), mt_rand(0, 0xffff));
-        $this->_logger->info(sprintf(
-            '[%s] Creating new folder uuid for %s: %s',
-            getmypid(),
+        $this->_logger->meta(sprintf(
+            'Creating new folder uuid for %s: %s',
             $id,
-            $this->_tempMap[$id]));
+            $this->_tempMap[$id])
+        );
 
         return $this->_tempMap[$id];
     }
