@@ -18,7 +18,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -31,7 +31,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -140,9 +140,9 @@ class Horde_ActiveSync_Message_Base
     public function __construct(array $options = array())
     {
         if (!empty($options['logger'])) {
-            $this->_logger = $options['logger'];
+            $this->_logger = Horde_ActiveSync::_wrapLogger($options['logger']);
         } else {
-            $this->_logger =  new Horde_Log_Logger(new Horde_Log_Handler_Null());
+            $this->_logger =  new Horde_ActiveSync_Log_Logger(new Horde_Log_Handler_Null());
         }
         if (!empty($options['protocolversion'])) {
             $this->_version = $options['protocolversion'];
@@ -586,7 +586,7 @@ class Horde_ActiveSync_Message_Base
                                 Horde_ActiveSync::AIRSYNCBASE_DATA,
                                 Horde_ActiveSync_Request_ItemOperations::ITEMOPERATIONS_DATA)
                               )) {
-                        $this->_logger->info('HANDLING MULTIPART OUTPUT');
+                        $this->_logger->meta('HANDLING MULTIPART OUTPUT');
                         $encoder->addPart($this->{$map[self::KEY_ATTRIBUTE]});
                         $encoder->startTag(Horde_ActiveSync_Request_ItemOperations::ITEMOPERATIONS_PART);
                         $encoder->content((string)(count($encoder->getParts()) - 1));
@@ -752,4 +752,4 @@ class Horde_ActiveSync_Message_Base
         return $newdata;
     }
 
-}
\ No newline at end of file
+}
