@@ -7,7 +7,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -19,7 +19,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -135,9 +135,9 @@ abstract class Horde_ActiveSync_State_Base
     {
         $this->_params = $params;
         if (empty($params['logger'])) {
-            $this->_logger =  new Horde_Log_Logger(new Horde_Log_Handler_Null());
+            $this->_logger =  new Horde_ActiveSync_Log_Logger(new Horde_Log_Handler_Null());
         } else {
-            $this->_logger = $params['logger'];
+            $this->_logger = Horde_ActiveSync::_wrapLogger($params['logger']);
         }
         $this->_procid = getmypid();
     }
@@ -237,7 +237,7 @@ abstract class Horde_ActiveSync_State_Base
      */
     public function setLogger($logger)
     {
-        $this->_logger = $logger;
+        $this->_logger = Horde_ActiveSync::_wrapLogger($logger);
     }
 
     /**
@@ -342,19 +342,18 @@ abstract class Horde_ActiveSync_State_Base
         $folders = $cache['folders'];
         foreach ($folders as $id => $folder) {
             if ($folder['serverid'] == $serverid) {
-                $this->_logger->info(sprintf(
-                    '[%s] Found serverid for %s: %s',
-                    $this->_procid,
-                    $serverid,
-                    $id));
+                $this->_logger->meta(sprintf(
+                    'STORAGE: Found serverid for %s: %s',
+                    $serverid, $id)
+                );
                 return $id;
             }
         }
 
-        $this->_logger->info(sprintf(
-            '[%s] No folderid found for %s',
-            $this->_procid,
-            $serverid));
+        $this->_logger->meta(sprintf(
+            'STORAGE: No folderid found for %s',
+            $serverid)
+        );
 
         return false;
     }
@@ -391,19 +390,15 @@ abstract class Horde_ActiveSync_State_Base
                 ? $this->_collection['filtertype']
                 : 0);
 
-            $this->_logger->info(sprintf(
-                '[%s] Initializing message diff engine for %s (%s)',
-                $this->_procid,
+            $this->_logger->meta(sprintf(
+                'STATE: Initializing message diff engine for %s (%s)',
                 $this->_collection['id'],
-                $this->_folder->serverid()
-                ));
+                $this->_folder->serverid())
+            );
 
             // Check for previously found changes first.
             if (!empty($this->_changes)) {
-                $this->_logger->info(sprintf(
-                    '[%s] Returning previously found changes.',
-                    $this->_procid)
-                );
+                $this->_logger->meta('STATE: Returning previously found changes.');
                 return $this->_changes;
             }
 
@@ -419,11 +414,11 @@ abstract class Horde_ActiveSync_State_Base
                 );
             }
 
-            $this->_logger->info(sprintf(
-                '[%s] Using SYNCSTAMP %s for %s.',
-                $this->_procid,
+            $this->_logger->meta(sprintf(
+                'STATE: Using SYNCSTAMP %s for %s.',
                 $this->_thisSyncStamp,
-                $this->_collection['id']));
+                $this->_collection['id'])
+            );
 
             // No existing changes, poll the backend
             $changes = $this->_backend->getServerChanges(
@@ -442,21 +437,16 @@ abstract class Horde_ActiveSync_State_Base
                 $this->_folder->updateState();
             }
 
-            $this->_logger->info(sprintf(
-                '[%s] Found %d message changes in %s.',
-                $this->_procid,
+            $this->_logger->meta(sprintf(
+                'STATE: Found %d message changes in %s.',
                 count($changes),
-                $this->_collection['id']));
+                $this->_collection['id'])
+            );
 
             // Check for mirrored client changes.
             $this->_changes = array();
             if (count($changes) && $this->_havePIMChanges()) {
-                $this->_logger->info(sprintf(
-                    '[%s] Checking for client initiated changes.',
-                    $this->_procid)
-                );
-
-                // As usual, Email is handled differently than other collections
+                $this->_logger->meta('STATE: Checking for client initiated changes.');
                 switch ($this->_collection['class']) {
                 case Horde_ActiveSync::CLASS_EMAIL:
                     // @todo Fix me with a changes object that transparently
@@ -500,9 +490,8 @@ abstract class Horde_ActiveSync_State_Base
                         }
                         $changes[$i]['ignore'] = true;
                         $this->_changes[] = $changes[$i];
-                        $this->_logger->info(sprintf(
-                            '[%s] Ignoring client initiated %s for %s',
-                            $this->_procid,
+                        $this->_logger->meta(sprintf(
+                            'STATE: Ignoring client initiated %s for %s',
                             $flag_map[$changes[$i]['type']],
                             $changes[$i]['id'])
                         );
@@ -527,9 +516,8 @@ abstract class Horde_ActiveSync_State_Base
                             $stat = $this->_backend->statMessage($this->_folder->serverid(), $changes[$i]['id']);
                         }
                         if ($client_timestamps[$changes[$i]['id']] >= $stat['mod']) {
-                            $this->_logger->info(sprintf(
-                                '[%s] Ignoring client initiated change for %s (client TS: %s Stat TS: %s)',
-                                $this->_procid,
+                            $this->_logger->meta(sprintf(
+                                'STATE: Ignoring client initiated change for %s (client TS: %s Stat TS: %s)',
                                 $changes[$i]['id'], $client_timestamps[$changes[$i]['id']], $stat['mod'])
                             );
                         } else {
@@ -538,10 +526,7 @@ abstract class Horde_ActiveSync_State_Base
                     }
                 }
             } elseif (count($changes)) {
-                $this->_logger->info(sprintf(
-                    '[%s] No client changes present, returning all messages.',
-                    $this->_procid)
-                );
+                $this->_logger->meta('STATE: No client changes, returning all messages.');
                 $this->_changes = $changes;
             }
         } else {
@@ -558,9 +543,7 @@ abstract class Horde_ActiveSync_State_Base
      */
     protected function _getFolderChanges()
     {
-        $this->_logger->info(sprintf(
-            '[%s] Initializing folder diff engine',
-            $this->_procid));
+        $this->_logger->meta('STATE: Initializing folder diff engine');
         $folderlist = $this->_backend->getFolderList();
         if ($folderlist === false) {
             return false;
@@ -581,14 +564,12 @@ abstract class Horde_ActiveSync_State_Base
             $folderlist);
 
         if (!count($this->_changes)) {
-            $this->_logger->info(sprintf(
-                '[%s] No folder changes found.',
-                $this->_procid));
+            $this->_logger->meta('STATE: No folder changes found.');
         } else {
-            $this->_logger->info(sprintf(
-                '[%s] Found %d folder changes.',
-                $this->_procid,
-                count($this->_changes)));
+            $this->_logger->meta(sprintf(
+                'STATE: Found %d folder changes.',
+                count($this->_changes))
+            );
         }
     }
 
@@ -606,8 +587,9 @@ abstract class Horde_ActiveSync_State_Base
     {
         if ($this->checkCollision($newKey = self::getNewSyncKey($syncKey))) {
             $this->_logger->err(sprintf(
-                '[%s] Found collision when generating synckey %s. Trying again.',
-                $this->_procid, $newKey));
+                'STATE: Found collision when generating synckey %s. Trying again.',
+                $newKey)
+            );
             return $this->getNewSyncKeyWrapper($synckey);
         }
 
@@ -862,9 +844,9 @@ abstract class Horde_ActiveSync_State_Base
         // synckey == 0 is an initial sync or reset.
         if (empty($syncKey)) {
             $this->_logger->notice(sprintf(
-                '[%s] %s::loadState: clearing folder state.',
-                $this->_procid,
-                __CLASS__));
+                '%s::loadState: clearing folder state.',
+                __CLASS__)
+            );
             if ($type == Horde_ActiveSync::REQUEST_TYPE_FOLDERSYNC) {
                 $this->_folder = array();
             } else {
@@ -878,11 +860,7 @@ abstract class Horde_ActiveSync_State_Base
             return;
         }
 
-        $this->_logger->info(
-            sprintf('[%s] Loading state for synckey %s',
-                $this->_procid,
-                $syncKey)
-        );
+        $this->_logger->meta(sprintf('STATE: Loading state for synckey %s', $syncKey));
 
         // Check if synckey is allowed. Throw a StateGone exception if it
         // doesn't match to give the client a chance to reset it's internal
