@@ -18,7 +18,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -31,7 +31,7 @@
  *            Version 2, the distribution of the Horde_ActiveSync module in or
  *            to the United States of America is excluded from the scope of this
  *            license.
- * @copyright 2009-2016 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2017 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   ActiveSync
  */
@@ -459,20 +459,12 @@ class Horde_ActiveSync_Wbxml_Encoder extends Horde_ActiveSync_Wbxml
      */
     private function _logStartTag($tag, $attr, $output_empty)
     {
-        $spaces = str_repeat(' ', count($this->_logStack));
+        $indent = count($this->_logStack);
         if ($output_empty) {
-            $this->_logger->debug(sprintf(
-                '[%s] O %s <%s/>',
-                $this->_procid,
-                $spaces,
-                $tag));
+            $this->_logger->server(sprintf('<%s>', $tag), $indent);
         } else {
             $this->_logStack[] = $tag;
-            $this->_logger->debug(sprintf(
-                '[%s] O %s <%s>',
-                $this->_procid,
-                $spaces,
-                $tag));
+            $this->_logger->server(sprintf('<%s>', $tag), $indent);
         }
     }
 
@@ -483,13 +475,9 @@ class Horde_ActiveSync_Wbxml_Encoder extends Horde_ActiveSync_Wbxml
      */
     private function _logEndTag()
     {
-        $spaces = str_repeat(' ', count($this->_logStack) - 1);
+        $indent = count($this->_logStack) - 1;
         $tag = array_pop($this->_logStack);
-        $this->_logger->debug(sprintf(
-            '[%s] O %s </%s>',
-            $this->_procid,
-            $spaces,
-            $tag));
+        $this->_logger->server(sprintf('</%s>', $tag), $indent);
     }
 
     /**
@@ -501,12 +489,8 @@ class Horde_ActiveSync_Wbxml_Encoder extends Horde_ActiveSync_Wbxml
      */
     private function _logContent($content)
     {
-        $spaces = str_repeat(' ', count($this->_logStack));
-        $this->_logger->debug(sprintf(
-            '[%s] O %s %s',
-            $this->_procid,
-            $spaces,
-            $content));
+        $indent = count($this->_logStack);
+        $this->_logger->server($content, $indent);
     }
 
-}
\ No newline at end of file
+}
